Classes
=======

The sections contained here document classes that can be used or subclassed.

.. note::
    Some of this information duplicates information available in the source
    code itself.  Consider this information authoritative, and the source code
    a demonstration of the current implementation which is subject to change.

.. toctree::
    :maxdepth: 1

    cls-buildfactory
    cls-remotecommands
    cls-buildsteps
    cls-forcesched

.. todo::

    cls-logobserver
